package com.gic.enterprise.service;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.enterprise.dto.PlatformBrandDTO;
import com.gic.enterprise.dto.PlatformBrandRefDTO;

import java.util.List;

/**
 * 平台品牌
 * @ClassName: PlatformBrandApiService
 * @Description: 平台品牌
 * @author zhiwj
 * @date 2019/8/5 16:26
 */
public interface PlatformBrandApiService {

    /**
     * gic添加一个平台级品牌
     * @Title: addBrandFromGic
     * @Description: 
     * @author zhiwj 
     * @param categoryId
     * @param platformBrandName
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Integer> id
     * @throws 
     */
    ServiceResponse<Integer> saveBrandFromGic(Integer categoryId, String platformBrandName);
    /**
     * 运维平台添加一个平台级品牌
     * @Title: addBrandFromOperation
     * @Description: 
     * @author zhiwj 
     * @param platformBrandDTO
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Integer> id
     * @throws 
     */
    ServiceResponse<Integer> saveOrUpdateBrandFromOperation(PlatformBrandDTO platformBrandDTO);

    /**
     * 根据id删除
     * @Title: delBrandById
     * @Description:
     * @author zhiwj 
     * @param platformBrandId
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Integer>
     * @throws 
     */
    ServiceResponse<Integer> delBrandById(Integer platformBrandId);

    /**
     * 查询品牌list， 条件为：名称:platformBrandName  类目:platformBrandCategoryId  来源:createType
     * @Title: listPlatformBrand
     * @Description:
     * @author zhiwj
     * @param platformBrandDTO
     * @return com.gic.api.base.commons.ServiceResponse<com.gic.api.base.commons.Page<com.gic.enterprise.dto.PlatformBrandDTO>>
     * @throws
     */
    ServiceResponse<Page<PlatformBrandDTO>> listPlatformBrand(PlatformBrandDTO platformBrandDTO, Integer pageNum, Integer pageSize);

    /**
     * 添加商户品牌和平台品牌的关联关系
     * @Title: addRef
     * @Description: 添加商户品牌和平台品牌的关联关系
     * @author zhiwj
     * @param enterpriseBrandName 商户品牌名
     * @param enterpriseBrandCode 商户品牌code
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Integer> 影响行数
     * @throws
     */
    ServiceResponse<Integer> addRef(Integer enterpriseId, Integer enterpriseBrandId, String enterpriseBrandName, String enterpriseBrandCode, Integer categoryId);

    /**
     * 删除一个关联关系
     * @Title: delRef
     * @Description: 删除一个关联关系
     * @author zhiwj 
     * @param enterpriseBrandId
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Integer>
     * @throws 
     */
    ServiceResponse<Integer> delRef(Integer enterpriseId, Integer enterpriseBrandId);

    /**
     * 删除一个关联关系
     * @Title: delRef
     * @Description: 删除一个关联关系
     * @author zhiwj
     * @param enterpriseBrandId
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Integer>
     * @throws
     */
    ServiceResponse<Integer> delRef(Integer enterpriseId, List<Integer> enterpriseBrandIds);

    /**
     * 更新一个关联关系
     * @Title: updateRef
     * @Description: 
     * @author zhiwj 
     * @param enterpriseBrandName
     * @param enterpriseBrandCode
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Integer>
     * @throws 
     */
    ServiceResponse<Integer> updateRef(Integer enterpriseId, Integer enterpriseBrandId, String enterpriseBrandName, String enterpriseBrandCode, Integer categoryId);

    /**
     * 按品牌名去查询详情
     * @Title: getByBrandName
     * @Description:
     * @author zhiwj
     * @param enterpriseBrandName
     * @return com.gic.api.base.commons.ServiceResponse<com.gic.enterprise.dto.PlatformBrandDTO>
     * @throws
     */
    ServiceResponse<PlatformBrandDTO> getByBrandName(String enterpriseBrandName);

    /**
     * 查询平台品牌对应的商品品牌
     * @Title: listByPlatformBrandRef
     * @Description:
     * @author zhiwj
     * @param brandName
     * @return com.gic.api.base.commons.ServiceResponse<com.gic.api.base.commons.Page<com.gic.enterprise.dto.PlatformBrandRefDTO>>
     * @throws
     */
    ServiceResponse<Page<PlatformBrandRefDTO>> listByPlatformBrandRef(String brandName, Integer pageNum, Integer pageSize);

    /**
     * 并入操作，将fromBrandId关联的商户品牌， 并入到toBrandId平台品牌下; 并删除fromBrandId平台品牌
     * @Title: mergeBrandRef
     * @Description: 
     * @author zhiwj 
     * @param fromBrandId
     * @param toBrandName
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Integer>
     * @throws 
     */
    ServiceResponse<Integer> mergeBrandRef(Integer fromBrandId, String toBrandName);


}
