package com.gic.enterprise.service.impl;

import com.gic.enterprise.constant.EnterpriseInitCodeEnum;
import com.gic.enterprise.dao.mapper.TabEnterpriseInitMapper;
import com.gic.enterprise.entity.TabEnterpriseInit;
import com.gic.enterprise.service.EnterpriseInitService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * @author guojx
 * @date 2019/7/18 11:13 AM
 */
@Service("enterpriseInitService")
public class EnterpriseInitServiceImpl implements EnterpriseInitService{
    @Autowired
    private TabEnterpriseInitMapper tabEnterpriseInitMapper;
    @Override
    public void initByCode(String configCode, Integer enterpriseId) {
        TabEnterpriseInit enterpriseInit = new TabEnterpriseInit();
        enterpriseInit.setEnterpriseId(enterpriseId);
        enterpriseInit.setConfigCode(configCode);
        enterpriseInit.setIsInitConfig(1);
        tabEnterpriseInitMapper.updateByEnterpriseIdSelective(enterpriseInit);
    }

    @Override
    public void initById(Integer initId) {
        TabEnterpriseInit enterpriseInit = new TabEnterpriseInit();
        enterpriseInit.setIsInitConfig(1);
        enterpriseInit.setEnterpriseInitId(initId);
        tabEnterpriseInitMapper.updateByPrimaryKeySelective(enterpriseInit);
    }

    @Override
    public TabEnterpriseInit getByCode(String configCode, Integer enterpriseId) {
        return tabEnterpriseInitMapper.getByCode(configCode, enterpriseId);
    }

    @Override
    public List<TabEnterpriseInit> listByParentId(Integer parentId, Integer enterpriseId) {
        List<TabEnterpriseInit> list = tabEnterpriseInitMapper.listByParentId(parentId, enterpriseId);
        if (list == null || list.size() < 1) {
            return new ArrayList<>();
        }
        return list;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void initEnterpriseConfigInfo(Integer enterpriseId) {
        tabEnterpriseInitMapper.deleteByEnterpriseId(enterpriseId);
        //
        tabEnterpriseInitMapper.initEnterpriseConfigInfo(enterpriseId);

        List<String> memberCardConfigList = new ArrayList<>(4);
        memberCardConfigList.add(EnterpriseInitCodeEnum.CreateMemberCard.getCode());
        memberCardConfigList.add(EnterpriseInitCodeEnum.CreateMemberGrade.getCode());
        tabEnterpriseInitMapper.updateParentIdBatch(enterpriseId, EnterpriseInitCodeEnum.CompleteMemberCardConfig.getCode(), memberCardConfigList);

        List<String> serviceNumberList = new ArrayList<>(4);
        serviceNumberList.add(EnterpriseInitCodeEnum.BindServiceNumber.getCode());
        serviceNumberList.add(EnterpriseInitCodeEnum.PerfectAutoReplyConfig.getCode());
        serviceNumberList.add(EnterpriseInitCodeEnum.PerfectMenuConfig.getCode());
        tabEnterpriseInitMapper.updateParentIdBatch(enterpriseId, EnterpriseInitCodeEnum.CompleteServiceNumberConfig.getCode(), serviceNumberList);

        List<String> weChatPageList = new ArrayList<>(4);
        weChatPageList.add(EnterpriseInitCodeEnum.PerfectWeChatPage.getCode());
        weChatPageList.add(EnterpriseInitCodeEnum.BindWeChat.getCode());
        tabEnterpriseInitMapper.updateParentIdBatch(enterpriseId, EnterpriseInitCodeEnum.CompleteWeChatConfig.getCode(), weChatPageList);
    }

    @Override
    public TabEnterpriseInit getById(Integer initId) {
        return tabEnterpriseInitMapper.selectByPrimaryKey(initId);
    }

}
