package com.gic.enterprise.service.outer;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.constant.EnterpriseInitCodeEnum;
import com.gic.enterprise.dto.EnterpriseInitDTO;
import com.gic.enterprise.entity.TabEnterprise;
import com.gic.enterprise.entity.TabEnterpriseInit;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.service.EnterpriseInitApiService;
import com.gic.enterprise.service.EnterpriseInitService;
import com.gic.enterprise.service.EnterpriseService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author guojx
 * @date 2019/7/18 11:31 AM
 */
@Service("enterpriseInitApiService")
public class EnterpriseInitApiServiceImpl implements EnterpriseInitApiService{
    @Autowired
    private EnterpriseInitService enterpriseInitService;
    @Autowired
    private EnterpriseService enterpriseService;
    @Override
    public ServiceResponse initByConfigCode(String configCode, Integer enterpriseId) {
        if (!EnterpriseInitCodeEnum.isRightCode(configCode)) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "初始化配置代码参数有误");
        }
        TabEnterprise enterprise = enterpriseService.getEnterpriseById(enterpriseId);
        if (enterprise == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "商户ID有误");
        }
        enterpriseInitService.initByCode(configCode, enterpriseId);
        //
        TabEnterpriseInit enterpriseInit = enterpriseInitService.getByCode(configCode, enterpriseId);
        if (enterpriseInit.getParentId() != 0) {
            //如果不是第一层，需要查询子节点是否都已经初始化，如果是，则父级节点自动初始化
            List<TabEnterpriseInit> listByParentId = enterpriseInitService.listByParentId(enterpriseInit.getParentId(), enterpriseId);
            boolean isChildrenAllInit = true;
            for (TabEnterpriseInit tabEnterpriseInit : listByParentId) {
                if (tabEnterpriseInit.getIsInitConfig() != 1) {
                    isChildrenAllInit = false;
                    break;
                }
            }
            if (isChildrenAllInit) {
                enterpriseInitService.initById(enterpriseInit.getEnterpriseInitId());
            }
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<List<EnterpriseInitDTO>> listByEnterpriseId(Integer enterpriseId) {
        TabEnterprise enterprise = enterpriseService.getEnterpriseById(enterpriseId);
        if (enterprise == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "商户ID有误");
        }
        List<TabEnterpriseInit> listByParentId = enterpriseInitService.listByParentId(null, enterpriseId);
        return ServiceResponse.success(EntityUtil.changeEntityListNew(EnterpriseInitDTO.class, listByParentId));
    }


}
