package com.gic.enterprise.service.outer;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.util.PageHelperUtils;
import com.gic.enterprise.constant.TransferAccountApprovalStatusEnum;
import com.gic.enterprise.dto.TransferAccountsApprovalDTO;
import com.gic.enterprise.dto.TransferAccountsApprovalDetailDTO;
import com.gic.enterprise.dto.TransferAccountsApprovalListDTO;
import com.gic.enterprise.entity.TabTransferAccountsApproval;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.service.TransferAccountsApprovalApiService;
import com.gic.enterprise.service.TransferAccountsApprovalService;
import com.gic.store.utils.valid.ValidUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

/**
 * @author guojx
 * @date 2019/7/19 10:03 AM
 */
@Service("transferAccountsApprovalApiService")
public class TransferAccountsApprovalApiServiceImpl implements TransferAccountsApprovalApiService{
    private static final Logger LOGGER = LoggerFactory.getLogger(TransferAccountsApprovalApiServiceImpl.class);
    @Autowired
    private TransferAccountsApprovalService transferAccountsApprovalService;
    @Override
    public ServiceResponse<Integer> initiateApproval(TransferAccountsApprovalDTO transferAccountsApprovalDTO) {
        //valid param
        ServiceResponse paramValid = ValidUtil.allCheckValidate(transferAccountsApprovalDTO, TransferAccountsApprovalDTO.InitiateApprovalValid.class);
        if (!paramValid.isSuccess()) {
            return paramValid;
        }

        transferAccountsApprovalDTO.setCreateTime(new Date());
        transferAccountsApprovalDTO.setUpdateTime(new Date());
        transferAccountsApprovalDTO.setApprovalStatus(TransferAccountApprovalStatusEnum.TO_BE_APPROVED.getCode());
        //审批流水号生成
        //时间+用户ID+几个随机数
        String approvalSerialNumber = transferAccountsApprovalDTO.getInitiatorId() + System.currentTimeMillis() + Math.random();
        LOGGER.info("转账审批-发起审批-审批流水号：{}", approvalSerialNumber);
        transferAccountsApprovalDTO.setApprovalNumber(approvalSerialNumber);

        transferAccountsApprovalService.initiateApproval(transferAccountsApprovalDTO);

        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<TransferAccountsApprovalDTO> getById(Integer transferApprovalId) {
        TabTransferAccountsApproval tab = transferAccountsApprovalService.getById(transferApprovalId);
        if (tab == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "转账审批主键有误");
        }
        return ServiceResponse.success(EntityUtil.changeEntityNew(TransferAccountsApprovalDTO.class, tab));
    }

    @Override
    public ServiceResponse agreeApproval(Integer transferApprovalId, Double accountAmount) {
        TabTransferAccountsApproval tab = transferAccountsApprovalService.getById(transferApprovalId);
        if (tab == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "转账审批主键有误");
        }
        TransferAccountsApprovalDTO dto = new TransferAccountsApprovalDTO();
        dto.setTransferApprovalId(transferApprovalId);
        dto.setAccountAmount(accountAmount);
        dto.setApprovalStatus(TransferAccountApprovalStatusEnum.AGREE.getCode());
        dto.setApprovalTime(new Date());
        //todo 审批人等信息获取插入
        transferAccountsApprovalService.updateTransferAccountsApproval(dto);
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse rejectApproval(Integer transferApprovalId) {
        TabTransferAccountsApproval tab = transferAccountsApprovalService.getById(transferApprovalId);
        if (tab == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "转账审批主键有误");
        }
        TransferAccountsApprovalDTO dto = new TransferAccountsApprovalDTO();
        dto.setTransferApprovalId(transferApprovalId);
        dto.setApprovalStatus(TransferAccountApprovalStatusEnum.REJECT.getCode());
        dto.setApprovalTime(new Date());
        //todo 审批人等信息获取插入
        transferAccountsApprovalService.updateTransferAccountsApproval(dto);
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Page<TransferAccountsApprovalListDTO>> listTransferAccountsApproval(String search, Integer approvalStatus,
                                                                                               Integer enterpriseId,
                                                                                               Integer pageNum, Integer pageSize) {
        com.github.pagehelper.Page page = transferAccountsApprovalService.listTransferAccountsApproval(search, approvalStatus, enterpriseId, pageNum, pageSize);
        Page<TransferAccountsApprovalListDTO> resultPage = PageHelperUtils.changePageHelperToCurrentPage(page);
        return ServiceResponse.success(resultPage);
    }

    @Override
    public ServiceResponse<TransferAccountsApprovalDetailDTO> getDetailById(Integer transferApprovalId) {
        TransferAccountsApprovalDetailDTO tab = transferAccountsApprovalService.getDetailById(transferApprovalId);
        if (tab == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "转账审批主键有误");
        }
        return ServiceResponse.success(tab);
    }


}
