package com.gic.operation.web.controller;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.gic.enterprise.constant.EnterpriseInitCodeEnum;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gic.auth.dto.UserDTO;
import com.gic.auth.service.UserApiService;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.constant.EnterpriseListOrderByEnum;
import com.gic.enterprise.constant.EnterpriseVersionStatusEnum;
import com.gic.enterprise.dto.EnterpriseDTO;
import com.gic.enterprise.dto.EnterpriseInitDTO;
import com.gic.enterprise.service.EnterpriseApiService;
import com.gic.enterprise.service.EnterpriseInitApiService;
import com.gic.operation.web.qo.PageQO;
import com.gic.operation.web.utils.UserPasswordUtil;
import com.gic.store.utils.CommonResultControllerUtils;

/**
 * 商户相关操作
 * @ClassName: EnterpriseController   
 * @Description:    
 * @author guojuxing   
 * @date 2019/8/7 5:23 PM  
 */
@RestController
@RequestMapping("/enterprise")
public class EnterpriseController {
    private static final Logger LOGGER = LoggerFactory.getLogger(EnterpriseController.class);
    @Autowired
    private EnterpriseApiService enterpriseApiService;
    @Autowired
    private UserApiService userApiService;
    @Autowired
    private EnterpriseInitApiService enterpriseInitApiService;

    @RequestMapping("/save-enterprise")
    public RestResponse saveEnterprise(
            @Validated({ EnterpriseDTO.SaveEnterpriseValid.class }) EnterpriseDTO enterpriseDTO,
            @Validated({ UserDTO.UserQoValid.class }) UserDTO userDTO) {
        String password = UserPasswordUtil.validPassword(userDTO.getPasswordType(), userDTO.getPassword(),
                userDTO.getConfirmPassword());
        userDTO.setPassword(UserPasswordUtil.getEncryptPassword(password));
        return RestResponse.success(
                CommonResultControllerUtils.commonResult(enterpriseApiService.saveEnterprise(enterpriseDTO, userDTO)));
    }

    @RequestMapping("/list-enterprise")
    public RestResponse listEnterprise(String search, Integer serviceVersion, Integer serviceStatus, Integer orderBy,
            PageQO pageQO) {
        if (orderBy == null) {
            orderBy = 0;
        }
        return RestResponse.success(CommonResultControllerUtils
                .commonResult(enterpriseApiService.listEnterprise(search, serviceVersion, serviceStatus,
                        EnterpriseListOrderByEnum.getOrderBy(orderBy), pageQO.getCurrentPage(), pageQO.getPageSize())));
    }

    @RequestMapping("/list-enterprise-version-status")
    public RestResponse listEnterpriseVersionStatus() {
        Map<Integer, String> resultMap = new HashMap<>(16);
        for (EnterpriseVersionStatusEnum statusEnum : EnterpriseVersionStatusEnum.values()) {
            resultMap.put(statusEnum.getCode(), statusEnum.getMessage());
        }
        return RestResponse.success(resultMap);
    }

    @RequestMapping("/list-enterprise-init-config-code")
    public RestResponse listEnterpriseInitConfigCode() {
        Map<String, String> resultMap = new HashMap<>(16);
        for (EnterpriseInitCodeEnum statusEnum : EnterpriseInitCodeEnum.values()) {
            resultMap.put(statusEnum.getCode(), statusEnum.getMessage());
        }
        return RestResponse.success(resultMap);
    }

    @RequestMapping("/init-enterprise")
    public RestResponse initEnterprise(Integer enterpriseId) {
        return RestResponse
                .success(CommonResultControllerUtils.commonResult(enterpriseApiService.initEnterprise(enterpriseId)));
    }

    @RequestMapping("/list-enterprise-init-info")
    public RestResponse listEnterpriseInitInfo(Integer enterpriseId) {
        List<EnterpriseInitDTO> dtoList = (List<EnterpriseInitDTO>) CommonResultControllerUtils
                .commonResult(enterpriseInitApiService.listByEnterpriseId(enterpriseId));
        return RestResponse.success(changeListToTree(0, dtoList));
    }

    @RequestMapping("/edit-enterprise")
    public RestResponse editEnterprise(@Validated({ EnterpriseDTO.EditEnterpriseValid.class,
            EnterpriseDTO.SaveEnterpriseValid.class }) EnterpriseDTO enterpriseDTO) {
        return RestResponse
                .success(CommonResultControllerUtils.commonResult(enterpriseApiService.editEnterprise(enterpriseDTO)));
    }

    @RequestMapping("/get-enterprise")
    public RestResponse editEnterprise(Integer enterpriseId) {
        return RestResponse.success(
                CommonResultControllerUtils.commonResult(enterpriseApiService.getEnterpriseById(enterpriseId)));
    }

    @RequestMapping("/enable-enterprise")
    public RestResponse enableEnterprise(Integer enterpriseId) {
        return RestResponse
                .success(CommonResultControllerUtils.commonResult(enterpriseApiService.enableEnterprise(enterpriseId)));
    }

    @RequestMapping("/disable-enterprise")
    public RestResponse disableEnterprise(Integer enterpriseId) {
        return RestResponse.success(
                CommonResultControllerUtils.commonResult(enterpriseApiService.disableEnterprise(enterpriseId)));
    }

    public static List<Map<String, Object>> changeListToTree(int initId, List<EnterpriseInitDTO> list) {
        List<Map<String, Object>> result = new ArrayList<>();
        if (list != null) {
            for (EnterpriseInitDTO t : list) {
                if (initId == t.getParentId()) {
                    Map<String, Object> data = new HashMap<>(16);
                    data.put("parentId", t.getParentId());
                    data.put("initId", t.getEnterpriseInitId());
                    data.put("configName", t.getConfigName());
                    data.put("sort", t.getSort());
                    data.put("isInitConfig", t.getIsInitConfig());
                    data.put("level", t.getLevel());
                    data.put("configUrl", t.getConfigUrl());
                    data.put("configCode", t.getConfigCode());
                    List<Map<String, Object>> children = changeListToTree(t.getEnterpriseInitId(), list);
                    data.put("children", children);
                    result.add(data);
                }
            }
        }
        return result;
    }
}
