package com.gic.operation.web.controller;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.dto.TransferAccountsApprovalDTO;
import com.gic.enterprise.dto.TransferAccountsApprovalDetailDTO;
import com.gic.enterprise.dto.TransferAccountsApprovalListDTO;
import com.gic.enterprise.response.EnterpriseRestResponse;
import com.gic.enterprise.service.TransferAccountsApprovalApiService;
import com.gic.operation.web.qo.PageQO;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author guojx
 * @date 2019/7/22 9:13 AM
 */
@RestController
@RequestMapping("/transfer-accounts-approval")
public class TransferAccountsApprovalController {
    private static final Logger LOGGER = LoggerFactory.getLogger(TransferAccountsApprovalController.class);

    @Autowired
    private TransferAccountsApprovalApiService transferAccountsApprovalApiService;

    /**
     * 发起审批
     * @param dto
     * @return
     */
    @RequestMapping("/initiate-approval")
    public RestResponse initiateApproval(TransferAccountsApprovalDTO dto) {
        ServiceResponse result = transferAccountsApprovalApiService.initiateApproval(dto);
        if (result.isSuccess()) {
            return RestResponse.success();
        } else {
            return EnterpriseRestResponse.failure(result);
        }
    }

    @RequestMapping("/get-approval")
    public RestResponse getById(Integer id) {
        ServiceResponse<TransferAccountsApprovalDetailDTO> result = transferAccountsApprovalApiService.getDetailById(id);
        if (result.isSuccess()) {
            return RestResponse.success(result.getResult());
        } else {
            return EnterpriseRestResponse.failure(result);
        }
    }

    @RequestMapping("/agree-approval")
    public RestResponse agreeApproval(Integer id, Double accountAmount) {
        ServiceResponse result = transferAccountsApprovalApiService.agreeApproval(id, accountAmount);
        if (result.isSuccess()) {
            return RestResponse.success();
        } else {
            return EnterpriseRestResponse.failure(result);
        }
    }

    @RequestMapping("/reject-approval")
    public RestResponse rejectApproval(Integer id) {
        ServiceResponse result = transferAccountsApprovalApiService.rejectApproval(id);
        if (result.isSuccess()) {
            return RestResponse.success();
        } else {
            return EnterpriseRestResponse.failure(result);
        }
    }

    @RequestMapping("/list-approval")
    public RestResponse listTransferAccountsApproval(String search, Integer approvalStatus,
                                                     Integer enterpriseId, PageQO pageQO) {
        ServiceResponse<Page<TransferAccountsApprovalListDTO>> result = transferAccountsApprovalApiService.listTransferAccountsApproval(search,
                approvalStatus, enterpriseId, pageQO.getCurrentPage(), pageQO.getPageSize());
        if (result.isSuccess()) {
            return RestResponse.success(result.getResult());
        } else {
            return EnterpriseRestResponse.failure(result);
        }
    }

}
