package com.gic.operation.web.controller;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.auth.constant.UserConstants;
import com.gic.auth.dto.UserDTO;
import com.gic.auth.service.UserApiService;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.response.EnterpriseRestResponse;
import com.gic.operation.web.utils.UserPasswordUtil;
import com.gic.store.constant.StoreGroupConstant;
import com.gic.store.utils.CommonResultControllerUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 用户操作
 * @ClassName: UserController   
 * @Description:    
 * @author guojuxing   
 * @date 2019/8/7 5:26 PM  
 */
@RestController
@RequestMapping("/user")
public class UserController {
    private static final Logger LOGGER = LoggerFactory.getLogger(UserController.class);
    @Autowired
    private UserApiService userApiService;

    @RequestMapping("/save-or-update-user")
    public RestResponse editUser(@Validated({ UserDTO.UserQoValid.class }) UserDTO userDTO) {
        userDTO.setEnterpriseId(StoreGroupConstant.TEST_ENTERPRISE_ID);
        String password = UserPasswordUtil.validPassword(userDTO.getPasswordType(), userDTO.getPassword(),
                userDTO.getConfirmPassword());
        userDTO.setPassword(UserPasswordUtil.getEncryptPassword(password));
        ServiceResponse userResult;
        if (userDTO.getUserId() == null) {
            userResult = userApiService.saveUser(userDTO);
        } else {
            userResult = userApiService.editUser(userDTO);
        }
        if (userResult.isSuccess()) {
            return RestResponse.success();
        } else {
            return EnterpriseRestResponse.failure(userResult);
        }
    }

    @RequestMapping("/get-user-by-id")
    public RestResponse getUserById(Integer userId) {
        return RestResponse.success(CommonResultControllerUtils.commonResult(userApiService.getUserById(userId)));
    }

    @RequestMapping("/get-user")
    public RestResponse getUser() {
        return RestResponse.success(CommonResultControllerUtils
                .commonResult(userApiService.getUserByEnterpriseId(StoreGroupConstant.TEST_ENTERPRISE_ID)));
    }
}
